@@ -141,3 +141,31 @@ def generatePnu(region_cd: str, jibun: str):
         "ji": ji,
         "msg": msg,
     }
+
+
+bjd_data = {}
+for idx, row in bjd.iterrows():
+    bjd_cd = str(row["bjd_cd"])
+    bjd_datum = {}
+    bjd_full_nm = []
+    for col in ["sido_nm", "sgg_nm", "emd_nm", "dl_nm"]:
+        if not pd.isna(row[col]):
+            bjd_datum[col] = row[col]
+            bjd_full_nm.append(row[col])
+        else:
+            bjd_datum[col] = None
+    bjd_datum["bjd_full_nm"] = " ".join(bjd_full_nm)
+    bjd_datum["created_dt"] = row["created_dt"]
+    bjd_datum["erased_dt"] = None if pd.isna(row["erased_dt"]) else row["erased_dt"]
+
+    bjd_data[bjd_cd] = bjd_datum
+
+
+def getBjd(bjd_cd: str):
+    try:
+        bjd_cd = str(bjd_cd)
+        if len(bjd_cd) != 10:
+            raise Exception("bjd_cd length should be 10:", bjd)
+        return {"error": False, **bjd_data[bjd_cd]}
+    except Exception as e:
+        return {"error": True, "msg": str(e)}
